import requests


class PoofAPI:
    def __init__(self, api_key):
        self.api_key = api_key
        self.base_url = "https://www.poof.io/api/v2"
        self.headers = {
            "Authorization": self.api_key,
            "content-type": "application/json"
        }

    def create_invoice(self, crypto, amount, metadata=None):
        url = f"{self.base_url}/create_invoice"
        payload = {
            "metadata": metadata,
            "crypto": crypto,
            "amount": amount
        }
        response = requests.post(url, json=payload, headers=self.headers)
        response.raise_for_status()
        return response.json()

    def create_charge(self, crypto, amount, metadata=None):
        url = f"{self.base_url}/create_charge"
        payload = {
            "metadata": metadata,
            "crypto": crypto,
            "amount": amount
        }
        response = requests.post(url, json=payload, headers=self.headers)
        response.raise_for_status()
        return response.json()

    def create_fiat_invoice(self, payment, currency, amount, redirect_url=None, success_url=None):
        url = f"{self.base_url}/create_fiat_invoice"
        payload = {
            "payment": payment,
            "currency": currency,
            "amount": amount,
            "redirect_url": redirect_url,
            "success_url": success_url
        }
        response = requests.post(url, json=payload, headers=self.headers)
        response.raise_for_status()
        return response.json()

    def create_fiat_charge(self, payment, currency, amount, redirect_url=None, success_url=None):
        url = f"{self.base_url}/create_fiat_charge"
        payload = {
            "payment": payment,
            "currency": currency,
            "amount": amount,
            "redirect_url": redirect_url,
            "success_url": success_url
        }
        response = requests.post(url, json=payload, headers=self.headers)
        response.raise_for_status()
        return response.json()

    def transaction(self, transaction_id):
        url = f"{self.base_url}/transaction"
        payload = {"transaction": transaction_id}
        response = requests.post(url, json=payload, headers=self.headers)
        response.raise_for_status()
        return response.json()

    def payout(self, crypto, amount, address):
        url = f"{self.base_url}/payouts"
        payload = {
            "amount": amount,
            "crypto": crypto,
            "address": address
        }
        response = requests.post(url, json=payload, headers=self.headers)
        response.raise_for_status()
        return response.json()

    def create_wallet(self, currency):
        url = f"{self.base_url}/create_wallet"
        payload = {"currency": currency}
        response = requests.post(url, json=payload, headers=self.headers)
        response.raise_for_status()
        return response.json()

    def balance(self, crypto):
        url = f"{self.base_url}/balance"
        payload = {"crypto": crypto}
        response = requests.post(url, json=payload, headers=self.headers)
        response.raise_for_status()
        return response.json()

    def price(self, crypto):
        url = f"{self.base_url}/price"
        payload = {"crypto": crypto}
        response = requests.post(url, json=payload, headers=self.headers)
        response.raise_for_status()
        return response.json()

    def create_webhook(self, url):
        url = f"{self.base_url}/create_webhook"
        payload = {"url": url}
        response = requests.post(url, json=payload, headers=self.headers)
        response.raise_for_status()
        return response.json()

    def fetch_product(self, product_id):
        url = f"{self.base_url}/fetch_product"
        payload = {"product_id": product_id}
        response = requests.post(url, json=payload, headers=self.headers)
        response.raise_for_status()
        return response.json()

    def gas_price(self, crypto):
        url = f"{self.base_url}/gas_price"
        payload = {"crypto": crypto}
        response = requests.post(url, json=payload, headers=self.headers)
        response.raise_for_status()
        return response.json()

    def contract_list(self):
        url = f"{self.base_url}/contract_list"
        response = requests.post(url, headers=self.headers)
        response.raise_for_status()
        return response.json()

    def checkout(self, payload):
        url = f"{self.base_url}/checkout"
        response = requests.post(url, json=payload, headers=self.headers)
        response.raise_for_status()
        return response.json()




from poof.api import (
    create_invoice,
    create_charge,
    create_fiat_invoice,
    create_fiat_charge,
    transaction,
    payout,
    create_wallet,
    balance,
    price,
    create_webhook,
    fetch_product,
    gas_price,
    contract_list,
    checkout
)

from poof.models import (
    Invoice,
    Charge,
    FiatInvoice,
    FiatCharge,
    Transaction,
    Payout,
    Wallet,
    Balance,
    Price,
    Webhook,
    Product,
    GasPrice,
    Contract,
    Checkout
)

__all__ = [
    "create_invoice",
    "create_charge",
    "create_fiat_invoice",
    "create_fiat_charge",
    "transaction",
    "payout",
    "create_wallet",
    "balance",
    "price",
    "create_webhook",
    "fetch_product",
    "gas_price",
    "contract_list",
    "checkout",
    "Invoice",
    "Charge",
    "FiatInvoice",
    "FiatCharge",
    "Transaction",
    "Payout",
    "Wallet",
    "Balance",
    "Price",
    "Webhook",
    "Product",
    "GasPrice",
    "Contract",
    "Checkout"
]


from setuptools import setup, find_packages

with open('README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()


setup(
    name='poofapi',
    version='1.0.2',
    description='A Python library for interacting with the Poof API',
    author='BreezDev',
    long_description=long_description,
    long_description_content_type='text/plain',
    author_email='itstheplugg@gmail.com',
    url='https://github.com/breezdev/poofapi',
    packages=find_packages(),
    install_requires=['requests'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ]
)



class Invoice:
    def __init__(self, id, crypto, amount, metadata=None):
        self.id = id
        self.crypto = crypto
        self.amount = amount
        self.metadata = metadata

class Charge:
    def __init__(self, id, crypto, amount, metadata=None):
        self.id = id
        self.crypto = crypto
        self.amount = amount
        self.metadata = metadata

class FiatInvoice:
    def __init__(self, id, payment, currency, amount, redirect_url=None, success_url=None):
        self.id = id
        self.payment = payment
        self.currency = currency
        self.amount = amount
        self.redirect_url = redirect_url
        self.success_url = success_url

class FiatCharge:
    def __init__(self, id, payment, currency, amount, redirect_url=None, success_url=None):
        self.id = id
        self.payment = payment
        self.currency = currency
        self.amount = amount
        self.redirect_url = redirect_url
        self.success_url = success_url

class Transaction:
    def __init__(self, id):
        self.id = id

class Payout:
    def __init__(self, crypto, amount, address):
        self.crypto = crypto
        self.amount = amount
        self.address = address

class Wallet:
    def __init__(self, currency):
        self.currency = currency

class Balance:
    def __init__(self, balance, crypto):
        self.balance = balance
        self.crypto = crypto

class Price:
    def __init__(self, usd, usd_24h_change):
        self.usd = usd
        self.usd_24h_change = usd_24h_change

class Webhook:
    def __init__(self, url):
        self.url = url

class Product:
    def __init__(self, product_id):
        self.product_id = product_id

class GasPrice:
    def __init__(self, gas_price):
        self.gas_price = gas_price

class Contract:
    def __init__(self, id, name, symbol, address):
        self.id = id
        self.name = name
        self.symbol = symbol
        self.address = address

class Checkout:
    def __init__(self, payload):
        self.payload = payload